@@ -145,22 +145,22 @@ class ExchangeToMsg(E2M):
 
 class Exchange(Account):
     __auto_renew = None
+    __auto_renew_thread = None
 
     """
     Lets make this a child class of Exchangelib's Account so that we can add renew_session()
     """
 
     def __init__(self, primary_smtp_address, fullname=None, access_type=None, autodiscover=False, credentials=None,
-                 config=None, locale=None, default_timezone=None):
+                 config=None, locale=None, default_timezone=None, auto_renew=False):
         Account.__init__(self, primary_smtp_address=primary_smtp_address, fullname=fullname, access_type=access_type,
                          autodiscover=autodiscover, credentials=credentials, config=config, locale=locale,
                          default_timezone=default_timezone)
 
         from threading import Thread
 
-        self.__auto_renew_thread = Thread(target=self.__auto_renew_session)
-        self.__auto_renew_thread.daemon = True
-        self.__auto_renew_thread.start()
+        if auto_renew:
+            self.start_auto_renew()
 
     def __auto_renew_session(self):
         from time import sleep
@@ -175,6 +175,19 @@ class Exchange(Account):
             sleep(1)
             counter += 1
 
+    def start_auto_renew(self):
+        if not self.__auto_renew_thread or not self.__auto_renew_thread.is_alive():
+            self.__auto_renew_thread = Thread(target=self.__auto_renew_session)
+            self.__auto_renew_thread.daemon = True
+            self.__auto_renew_thread.start()
+
+    def stop_auto_renew(self):
+        if self.__auto_renew_thread and self.__auto_renew_thread.is_alive():
+            self.__auto_renew = False
+            self.__auto_renew_thread.join()
+
+        self.__auto_renew_thread = None
+
     def renew_session(self):
         """
         Renew e-mail session by retiring old session and starting new session. Great way to keep the connection live
