@@ -155,7 +155,8 @@ class TBoxBase(object):
 class Toolbox(TBoxBase, SQLQueue, LogHandle):
     DEFAULT_CONNECTION_SIZE = 10
 
-    def __init__(self, script_path, logging_dir=None, logging_base_name=None, max_pool_size=None, *args, **kwargs):
+    def __init__(self, script_path, logging_dir=None, logging_folder=None, logging_base_name=None, max_pool_size=None,
+                 *args, **kwargs):
         TBoxBase.__init__(self, script_path=script_path)
         SQLQueue.__init__(self, max_pool_size=max_pool_size)
         LogHandle.__init__(self)
@@ -165,8 +166,8 @@ class Toolbox(TBoxBase, SQLQueue, LogHandle):
 
         if logging_dir and os.path.exists(logging_dir) and os.path.isdir(logging_dir):
             file_dir = logging_dir
-        elif self.local_config_dir:
-            file_dir = self.local_config_dir
+        elif self.local_config_dir and logging_folder:
+            file_dir = os.path.join(self.local_config_dir, logging_folder)
 
         if file_dir:
             if logging_base_name:
